@@ -9,7 +9,8 @@ import sys
 from vulture import lines
 from vulture import noqa
 from vulture import utils
-from vulture.config import make_config
+from vulture.config import InputError, make_config
+from vulture.utils import ExitCode
 
 
 DEFAULT_CONFIDENCE = 60
@@ -217,7 +218,7 @@ class Vulture(ast.NodeVisitor):
 
         self.filename = Path()
         self.code = []
-        self.found_dead_code_or_error = False
+        self.exit_code = ExitCode.NoDeadCode
 
     def scan(self, code, filename=""):
         filename = Path(filename)
@@ -232,7 +233,7 @@ class Vulture(ast.NodeVisitor):
                 file=sys.stderr,
                 force=True,
             )
-            self.found_dead_code_or_error = True
+            self.exit_code = ExitCode.InvalidInput
 
         try:
             node = (
@@ -251,7 +252,7 @@ class Vulture(ast.NodeVisitor):
                 file=sys.stderr,
                 force=True,
             )
-            self.found_dead_code_or_error = True
+            self.exit_code = ExitCode.InvalidInput
         else:
             # When parsing type comments, visiting can throw SyntaxError.
             try:
@@ -287,7 +288,7 @@ class Vulture(ast.NodeVisitor):
                     file=sys.stderr,
                     force=True,
                 )
-                self.found_dead_code_or_error = True
+                self.exit_code = ExitCode.InvalidInput
             else:
                 self.scan(module_string, filename=module)
 
@@ -353,8 +354,8 @@ class Vulture(ast.NodeVisitor):
                 else item.get_report(add_size=sort_by_size),
                 force=True,
             )
-            self.found_dead_code_or_error = True
-        return self.found_dead_code_or_error
+            self.exit_code = ExitCode.DeadCode
+        return self.exit_code
 
     @property
     def unused_classes(self):
@@ -726,7 +727,12 @@ class Vulture(ast.NodeVisitor):
 
 
 def main():
-    config = make_config()
+    try:
+        config = make_config()
+    except InputError as e:
+        print(e, file=sys.stderr)
+        sys.exit(ExitCode.InvalidCmdlineArguments)
+
     vulture = Vulture(
         verbose=config["verbose"],
         ignore_names=config["ignore_names"],
